import { IOriginModelingData, ModelType } from '../../../Production/Product';
export declare abstract class BaseModel {
    protected get props(): any[];
    ToArray(): any[];
}
export declare class CadBlockPoint extends BaseModel {
    PointID: number;
    PointX: number;
    PointY: number;
    Curve: number;
    SealSize: number;
    SealColor: string;
    ReservedEdge: number;
    protected get props(): string[];
    ToArray(): any[];
}
export declare class CadBlockHoles extends BaseModel {
    HoleID: number;
    HoleType: HoleType;
    Face: FaceType;
    PointX: number;
    PointY: number;
    PointZ: number;
    Radius: number;
    Depth: number;
    EndPoint: string;
    PointX2: number;
    PointY2: number;
    Angle?: number;
    protected get props(): string[];
}
export declare enum HoleType {
    大孔 = 0,
    小孔 = 10,
    木削 = 20,
    木削大孔 = 21,
    层板钉 = 30,
    通孔 = 40,
    连接杆 = 50,
    造型孔 = -10
}
export declare enum FaceType {
    正面 = 0,
    反面 = 1,
    侧面 = 2
}
export declare class CadBlockModel extends BaseModel {
    ModelID: number;
    LineID: number;
    Face: FaceType;
    KnifeName: string;
    KnifeRadius: number;
    Depth: number;
    PointList: CadBlockModelPoint[];
    OffSetList: ModelOffSetData[];
    OriginModeling: IOriginModelingData;
    ModelType: ModelType;
    ChaiDanName: string;
    protected get props(): string[];
    ToArray(): (string | number | any[])[];
}
export declare class ModelOffSetData extends BaseModel {
    Name: string;
    Face: FaceType;
    Value: number;
    Radius: number;
    Deep: number;
    Angle: number;
    ToArray(): (string | number)[];
}
export declare class CadBlockModelPoint extends BaseModel {
    LineID: number;
    PointID: number;
    PointX: number;
    PointY: number;
    Radius: number;
    Depth: number;
    Curve: number;
    protected get props(): string[];
}
export declare class BasePosition extends BaseModel {
    BasePoint: string;
    XVec: string;
    YVec: string;
    ZVec: string;
    protected get props(): string[];
}
export declare class CadBlockInfo {
    PointDetail: CadBlockPoint[];
    HoleDetail: CadBlockHoles[];
    ModelDetail: CadBlockModel[];
    OrgPointDetail: CadBlockPoint[];
    SideModelDetail: CadBlockModel[];
    SideHoleDetail: CadBlockHoles[];
}
export declare class CadSealInfoPoint {
    PointID: number;
    SealSize: number;
    SealColor: string;
    ReservedEdge: number;
}
//# sourceMappingURL=CadBlockInfo.d.ts.map