import { Vector3 } from "three";
import { Board } from "../../DatabaseServices/Entity/Board";
import { Entity } from "../../DatabaseServices/Entity/Entity";
import { Polyline } from "../../DatabaseServices/Entity/Polyline";
import { IBoardHoleInfo, IOriginSideModelingData, ISpliteOrderData } from "../../Production/Product";
/**
 * 根据配置的板件信息规则，获取对应的板件信息
 * @param {Board} br 板件
 * @param {string} [ruleStr=""] 规则
 * @return {*}  {string}
 */
export declare function GetBoardInfoByRule(br: Board, ruleStr: string): string;
/**
 * 加减乘除运算，并格式化到小数点后一位
 * 注意：1、参数a必须为有效数字（number或数值类字符串）
 *       2、若运算错误，返回a的值（如operator不是加减乘除之一，或者b转换后为无效数字，或者除数为0）)
 * @param {(number | string)} a
 * @param {string} [operator]
 * @param {(number | string)} [b]
 * @return {*}  {(number)}
 */
export declare function Calculate(a: number | string, operator?: string, b?: number | string): string;
/**
 * 替换规则花括号中的字段为具体值。
 * 若值为数值，可进行数学运算：{长 运算符 数字}如  {长*100} => 5
 * @param {string} ruleStr 规则字符串 如：{长} - {宽}
 * @param {[string, string][]} paramsList 中英文对应参数列表 如：[["长", "Length"], ["宽", "Width"]]
 * @param {(key: string, operator?: string, calValue?: string) => string} getParamCorrValue 获取参数对应的值
 * @return {*}  {string} 按规则字符串计算后的结果
 */
export declare function ReplaceRuleFieldWithCorrValue(ruleStr: string, paramsList: [string, string][], getParamCorrValue: (key: string, operator?: string, calValue?: string) => string): string;
export declare function DrawHole(holeInfo: IBoardHoleInfo, offset: Vector3): Promise<Entity[]>;
export declare function DrawSideHole(sideHoleInfo: IOriginSideModelingData[], sealingContour: Polyline, offset: Vector3): Entity[];
export declare function DrawOriginModeling(br: Board, info: ISpliteOrderData): Entity[];
//# sourceMappingURL=ConfigUtils.d.ts.map