import type { ILayerNode } from "./Type";
/** 针对图层的数据转换器(Data层->View层)
 * @description 该类用于将图层的Data层数据转换为图层的View层数据，便于Undo操作
 * 如：当图纸颜色被改变时(此时Undo只会撤销Data层数据)，通过该类可以更新View层数据，实现UI状态的同步改变
 * 比如，LayerCMD中有个方法UpdateColor，该方法用于更新图层的UI颜色(View层)
 * 再调用DataToViewForLayer中的UpdateColor方法，使得layerTableRecord的颜色(Data层)也同步更新
 */
export declare class DataToViewForLayer {
    /** 根据Table更新Root(注意这里采用少补不多还) */
    static UpdateRootByTable(): void;
    /** 全量更新(根据Root+Record更新View层数据) */
    static UpdateAll(): void;
}
/** 针对图层的数据转换器(View层->Data层)
 * @description 该类用于将图层的View层数据转换为图层的Data层数据，便于数据库的读写
 * 如：锁定按钮被点击时(只需要关心按钮状态的UI数据)，调用该类对应的方法即可实现图层的锁定功能
 */
export declare class ViewToDataForLayer {
    /** 创建图层 */
    static AppendLayer(node: ILayerNode): void;
    /** 创建图层文件夹 */
    static AppendLayerFolder(node: ILayerNode): void;
    /** 删除图层 */
    static RemoveLayer(node: ILayerNode, moveWhere: string): void;
    /** 置为当前图层 */
    static SetCurrentLayer(): void;
    /** 设置是否显示 */
    static UpdateShow(node: ILayerNode): void;
    /** 设置是否锁定 */
    static UpdateLock(node: ILayerNode): void;
    /** 设置是否视口冻结  */
    static UpdateViewPoint(node: ILayerNode): void;
    /** 设置颜色 */
    static UpdateColor(node: ILayerNode): void;
    /** 重命名图层 */
    static RenameLayer(oldName: string, newName: string): void;
    /** 移动图层 */
    static MoveLayer(node: ILayerNode): void;
}
//# sourceMappingURL=Transform.d.ts.map